//
//  NetworkAdsListView.swift
//  SampleApp
//
//  Created by Nishan on 29/5/2567 BE.
//  Copyright © 2567 BE David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct NetworkAdsListView: View {
    
    @StateObject var viewModel = NetworkAdsListViewModel()
    
    @State private var showPlacementOptions = false
    
    var placementOptions: [AmityAdPlacement] = [.chat, .chatList, .comment, .feed, .story]
    
    var body: some View {
        
        ScrollView {
            
            Text("Settings:\n\(viewModel.settings?.modelDescription ?? "")")
                .frame(maxWidth: .infinity, alignment: .leading)
                .padding()
            
            Divider()
            
            ForEach(viewModel.ads) { item in
                Text(item.modelDescription)
                    .frame(maxWidth: .infinity, alignment: .leading)
                    .padding()
                    .contextMenu(ContextMenu(menuItems: {
                        
                        Menu("Mark as seen") {
                            ForEach(placementOptions, id: \.rawValue) { placement in
                                Button(placement.rawValue) {
                                    item.analytics.markAsSeen(placement: placement)
                                }
                            }
                        }
                        
                        Menu("Mark link as clicked") {
                            ForEach(placementOptions, id: \.rawValue) { placement in
                                Button(placement.rawValue) {
                                    item.analytics.markLinkAsClicked(placement: placement)
                                }
                            }
                        }
                        
                    }))
            }
        }
        .onAppear {
            viewModel.fetchAllAds()
        }
    }
}

#Preview {
    NetworkAdsListView()
}

class NetworkAdsListViewModel: ObservableObject {
    
    @Published var ads = [AmityAd]()
    @Published var settings: AmityAdsSettings?
    
    lazy var adRepo = AmityAdRepository(client: AmityManager.shared.client!)
    
    func fetchAllAds() {
        Task { @MainActor in
            do {
                let networkAds = try await adRepo.getNetworkAds()
                self.ads = networkAds.ads
                self.settings = networkAds.settings
            } catch let error {
                
            }
        }
    }
}

extension AmityAd: Identifiable {
    
    public var id: String {
        return self.adId
    }
    
    var modelDescription: LocalizedStringKey {
        return """
        **Ad:**
        Id: \(self.adId)
        Advertiser Id: \(self.advertiserId)
        Name: \(self.name)
        Placements: \(self.placements.map { $0.rawValue }.joined(separator: ","))
        Headline: \(self.headline)
        Description: \(self.description)
        Body: \(self.body)
        Image1_1: \(self.image1_1?.fileId ?? "-")
        Image9_16: \(self.image9_16?.fileId ?? "-")
        Call To Action: \(self.callToAction)
        Call To Action Url: \(self.callToActionUrl)
        Targets: \(String(describing: self.target?.communityIds ?? []))
        Started At: \(self.startedAt?.formatted(date: .numeric, time: .shortened) ?? "-")
        End At: \(self.endAt?.formatted(date: .numeric, time: .shortened) ?? "-")
        Created At: \(self.createdAt?.formatted(date: .numeric, time: .shortened) ?? "-")
        Updated At: \(self.updatedAt?.formatted(date: .numeric, time: .shortened) ?? "-")
        **Advertiser Info:** \n\(self.advertiser?.modelDescription ?? "")
        """
    }
}

extension AmityAdImage {
    
    var modelDescription: String {
        return """
        Type: \(self.type)
        FileId: \(self.fileId)
        Image (Linked Object): \(image == nil ? "Not Found" : "Linked")
        """
    }
}

extension AmityAdsSettings {
    
    var modelDescription: String {
        return """
        Enabled: \(self.enabled)
        Max Active ads: \(self.maxActiveAds)
        Frequency: \(self.frequency?.modelDescription ?? "")
        """
    }
}

extension AmityFrequencySettings {
    
    var modelDescription: String {
        return """
        - Story: \(self.story?.modelDescription ?? "")
        - Feed: \(self.feed?.modelDescription ?? "")
        - Comment: \(self.comment?.modelDescription ?? "")
        """
    }
}

extension AmityAdFrequency {
    
    var modelDescription: String {
        return """
        Type: \(self.type) Value: \(self.value)
        """
    }
}

extension AmityAdvertiser {
    
    var modelDescription: String {
        return """
         - Id: \(self.advertiserId)
         - Name: \(self.name)
         - Company Name: \(self.companyName)
         - Avatar File Id: \(self.avatarField)
         - Avatar (Linked Object): \(avatar == nil ? "Not Found" : "Linked")
         - Created At: \(self.createdAt?.formatted(date: .numeric, time: .shortened) ?? "-")
         - Updated At: \(self.updatedAt?.formatted(date: .numeric, time: .shortened) ?? "-")
        """
    }
}
