//
//  MultiplePostQueryView.swift
//  SampleApp
//
//  Created by Zay Yar Htun on 7/11/24.
//  Copyright © 2024 David Zhang. All rights reserved.
//

import Foundation
import SwiftUI

struct MultiplePostQueryView: View {
    
    @Environment(\.dismiss) var dismissScreen
    
    struct Input: Identifiable {
        let id: UUID = UUID()
        var text: String = ""
    }
    
    @State private var allInputs: [Input] = []
    
    var body: some View {
        List {
            ForEach($allInputs) { item in
                TextField("Post Id", text: item.text)
            }
            .onDelete(perform: { indexSet in
                delete(at: indexSet)
            })
            
            Section() {
                let allPostIds = allInputs.compactMap {
                    let id = $0.text.trimmingCharacters(in: .whitespacesAndNewlines)
                    if !id.isEmpty {
                        return id
                    } else {
                        return nil
                    }
                }
                
                NavigationLink(destination: PostListPage(postIds: allPostIds)) {
                    HStack {
                        Spacer()
                        Text("Query Posts")
                        Spacer()
                    }
                }
            }
            .disabled(allInputs.isEmpty)
            .accessibilityIdentifier("query-post-button")
        }
        .navigationTitle("Post Id")
        .navigationBarTitleDisplayMode(.inline)
        .toolbar(content: {
            Button(action: {
                allInputs.append(Input(text: ""))
            }, label: {
                Image(systemName: "plus")
            })
            .accessibilityIdentifier("add-new-post-id-button")
        })
    }
    
    func delete(at offsets: IndexSet) {
        allInputs.remove(atOffsets: offsets)
    }
}
