//
//  SubChannelDetailsView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 14/3/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct SubChannelDetail: Identifiable {
    var id: String
    
    var subChannel: AmitySubChannel?
    var type: String = ""
    var displayName: String = ""
    var channelId: String = ""
    var subChannelId: String = ""
    var unreadCount: Int = 0
    var hasMentioned: Bool = false
    var isUnreadCountSupported: Bool = false
    var messageCount: Int = 0
    var isDeleted: Bool = false
    var latestMessageId: String = ""
    var lastActivity: Date?
    var creatorId: String = ""
    var createdAt: Date?
    var editedAt: Date?
    var updatedAt: Date?
    
    init(object: AmitySubChannel) {
        id = object.subChannelId
        subChannel = object
        channelId = object.channelId
        subChannelId = object.subChannelId
        type = object.channelType.description
        displayName = object.displayName
        messageCount = object.messageCount
        unreadCount = object.unreadCount
        hasMentioned = object.isMentioned
        isUnreadCountSupported = object.isUnreadCountSupported
        isDeleted = object.isDeleted
        latestMessageId = object.latestMessageId ?? ""
        lastActivity = object.lastActivity
        creatorId = object.creatorId
        createdAt = object.createdAt
        updatedAt = object.updatedAt
        editedAt = object.editedAt
    }
}

struct SubChannelDetailsView: View {
    
    @ObservedObject var viewModel: SubChannelDetailsViewModel
    @State var avatarInfo: String = ""
    
    var body: some View {
        VStack {
            
            Text(viewModel.subChannelObject?.snapshot?.modelDescription ?? "")
                .padding([.leading, .trailing], 10)
                .accessibilityIdentifier("subchannel-detail-text")
            
        }.navigationBarTitle("Sub Channel Details", displayMode: .inline)
            .onAppear() {
                viewModel.getSubChannel()
            }
    }
}

struct SubChannelDetailsView_Previews: PreviewProvider {
    static var previews: some View {
        Text("Sub channel detail")
    }
}

// Concrete implementor
class SubChannelDetailsViewModel: ObservableObject {
    
    var subChannelId: String
    
    var subChannelObject: AmityObject<AmitySubChannel>?
    
    private var token: AmityNotificationToken?
    private let subChannelRepo = AmitySubChannelRepository(client: AmityManager.shared.client!)

    @Published var subChannelDetail: SubChannelDetail?
    
    init(subChannelId: String) {
        self.subChannelId = subChannelId
    }
    
    func getSubChannel() {
        token?.invalidate()
        
        subChannelObject = subChannelRepo.getSubChannel(withId: subChannelId)
        token = subChannelObject?.observe({ [weak self] subChannel, error in
            guard let object = subChannel.snapshot, let self else { return }
            let subChannelDetail = SubChannelDetail(object: object)
            self.subChannelDetail = subChannelDetail
        })
    }
    
}
