//
//  AppSettingsView.swift
//  SampleApp
//
//  Created by Nishan on 2/7/2567 BE.
//  Copyright © 2567 BE David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct AppSettingsView: View {
    
    @State private var isFileAccessModePrivate = false
    
    @State private var alertTitle = ""
    @State private var isAlertShown = false
    
    var body: some View {
        Form {
            fileAccessModeSettings
        }
        .onChange(of: isFileAccessModePrivate) { value in
            AmityManager.shared.client?.setUploadedFileAccessType(type: isFileAccessModePrivate ? .network : .public)
            
            alertTitle = "File access mode is set to \(isFileAccessModePrivate ? "Network" : "Public")"
        }
        .alert(alertTitle, isPresented: $isAlertShown) { }
    }
    
    @ViewBuilder
    var fileAccessModeSettings: some View {
        Section("File Access Mode") {
            Button(action: {
                isFileAccessModePrivate = true
                isAlertShown = true
            }, label: {
                Text("Set file access mode: Network")
                    .frame(maxWidth: .infinity, alignment: .leading)
                    .contentShape(Rectangle())
            })
            
            Button(action: {
                isFileAccessModePrivate = false
                isAlertShown = true
            }, label: {
                Text("Set file access mode: Public")
                    .frame(maxWidth: .infinity, alignment: .leading)
                    .contentShape(Rectangle())
            })
        }
        .buttonStyle(.plain)
    }
}

#Preview {
    AppSettingsView()
}
