//
//  NetworkActivityView.swift
//  SampleApp
//
//  Created by Nishan on 10/7/2567 BE.
//  Copyright © 2567 BE David Zhang. All rights reserved.
//

import SwiftUI

struct NetworkActivityView: View {
    
    @StateObject var observer: NetworkActivityObserver = .shared
    
    var body: some View {
        NavigationView {
            List {
                ForEach(observer.activities) { activity in
                    Text(activity.text)
                        .font(.body)
                        .foregroundStyle(.primary)
                }
            }
            .listStyle(.plain)
            .navigationTitle("Network Logs")
            .navigationBarTitleDisplayMode(.inline)
            .toolbar(content: {
                ToolbarItem(placement: .navigation) {
                    Button(action: {
                        NetworkActivityObserver.shared.activities = []
                    }, label: {
                        Text("Clear")
                    })
                }
            })
        }
    }
}

#Preview {
    NetworkActivityView()
}

class NetworkActivityObserver: ObservableObject {
    
    @Published var activities: [ActivityLog] = []
    
    static let shared = NetworkActivityObserver()
    
    init() {
        AmityManager.shared.client?.observeNetworkActivities({ [weak self] request, response, data in
            let requestURL = request?.url?.absoluteString ?? ""
            let requestMethod = request?.httpMethod ?? ""
            let statusCode = response?.statusCode ?? 0
            
            let log = "› Request: [\(requestMethod)] \(requestURL)\n› Response: \(statusCode)"
            self?.activities.append(ActivityLog(text: log))
        })
    }
}

struct ActivityLog: Identifiable {
    let id: UUID = .init()
    let text: String
}
